<?xml version="1.0"?>
<package format="3">
    <name>{{ id }}</name>
    <version>0.1.0</version>
    <description>{{ name }}</description>

  <!-- One maintainer tag required, multiple allowed, one person per tag -->
  <!-- Example:  -->
  <!-- <maintainer email="jane.doe@example.com">Jane Doe</maintainer> -->
  <maintainer email="todo@todo.todo">TODO</maintainer>

  <!-- One license tag required, multiple allowed, one license per tag -->
  <!-- Commonly used license strings: -->
  <!--   BSD, MIT, Boost Software License, GPLv2, GPLv3, LGPLv2.1, LGPLv3 -->
  <license>Proprietary</license>

  <!-- Url tags are optional, but multiple are allowed, one per tag -->
  <!-- Optional attribute type can be: website, bugtracker, or repository -->
  <!-- Example: -->
  <!-- <url type="website">http://wiki.ros.org/test</url> -->


  <!-- Author tags are optional, multiple are allowed, one per tag -->
  <!-- Authors do not have to be maintainers, but could be -->
  <!-- Example: -->
  <!-- <author email="jane.doe@example.com">Jane Doe</author> -->


  <!-- The *depend tags are used to specify dependencies -->
  <!-- Dependencies can be catkin packages or system dependencies -->
  <buildtool_depend>catkin</buildtool_depend>
  <depend>rospy</depend>
  <depend>actionlib</depend>
  <depend>hri_actions_msgs</depend>

{% if robot == "ARI" %}

  <!-- As an example, we are going to use the TTS and play_motion -->
  <!-- actions. We need to list the corresponding ROS actions as dependencies. -->
  <depend>pal_interaction_msgs</depend>
  <depend>play_motion_msgs</depend>

{% endif %}
  <export>
      <!-- This specifies that this package should be treated as an -->
      <!-- application. -->
      <!-- Do not remove! -->
      <role>application</role>
  </export>
</package>
