cmake_minimum_required(VERSION 3.2.0)
project({{ id }})

find_package(catkin REQUIRED
            rospy
            actionlib
            hri_actions_msgs
{% if robot == "ARI" %}
            # As an example, we are going to use the TTS and play_motion
            # actions. We need to list the corresponding ROS actions as dependencies.
            pal_interaction_msgs
            play_motion_msgs
{% endif %}
            )

catkin_python_setup()
catkin_package()

catkin_install_python(PROGRAMS
   scripts/run_app
   DESTINATION ${CATKIN_PACKAGE_BIN_DESTINATION}
)

add_custom_target(pkg COMMAND
    ${CMAKE_COMMAND} -E tar "cfv" "{{ id }}.rpk" --format=zip
       "${CMAKE_CURRENT_SOURCE_DIR}")
